package XTM::Namespaces;

use vars qw($topicmap_ns $xlink_ns $astma_ns);

$topicmap_ns = 'http://www.topicmaps.org/xtm/1.0/';
$xlink_ns    = 'http://www.w3.org/1999/xlink';
$astma_ns    = 'http://topicmaps.bond.edu.au/astma/1.0/';

1;
